;;; Plugin  : Chalk Painter
;;; Author  : Rod Detmer
;;; Date    : November 2015
;;; Revision: None
;;; 					
;;; Version : 1.0
;;; Latest version at: http://www.gimpchat.com
;;; Required : Gimp 2.8 or later
;;;
;;; Description: 
;;; creates a painting type effect on an image. Images with more colors result in a better outcome
;;; -----------------------------------------------------------------------------
;;;
;;; License:
;;; This program is free software; you can redistribute it and/or modify
;;; it under the terms of the GNU General Public License as published by
;;; the Free Software Foundation; either version 2 of the License, or
;;; (at your option) any later version.
;;; 
;;; This program is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;; 
;;; You should have received a copy of the GNU General Public License
;;; along with this program; if not, write to the Free Software
;;; Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

(define (script-fu-chalk-painter image drawable contrast layer_mode)
  
  (gimp-context-push)  
  (gimp-image-undo-group-start image)
  
 	;desaturate the image first
  (gimp-desaturate drawable)
    ;make all visible chalklayer and run new from visible making sure its named Chalk layer
            (let* ((chalklayer (car (gimp-layer-new-from-visible image image "Chalk layer"))))

   ;add the visible image to a new layer 
  (gimp-image-add-layer image chalklayer 0)
  
    ;begin paint effect on new layer
  (plug-in-neon RUN-NONINTERACTIVE image chalklayer 6.10 0.07)


   
   ;paint by spreading pixels around the top layer
  (plug-in-spread RUN-NONINTERACTIVE image chalklayer 3 3)   
  (plug-in-neon RUN-NONINTERACTIVE image chalklayer 1.0 1.0)  
  (gimp-layer-set-mode chalklayer layer_mode)
  
  ;set paint depth
  (gimp-layer-set-opacity chalklayer 100)
  (gimp-brightness-contrast chalklayer 0 contrast)
  (plug-in-gauss 1 image chalklayer 3 3 1)
  ;(gimp-invert chalklayer)
  ;(gimp-layer-copy chalklayer 0)
  ;display the new image
  (gimp-displays-flush image)
  
  (gimp-context-pop)
  (gimp-image-undo-group-end image)
            )
  
)


(script-fu-register "script-fu-chalk-painter"
"Chalk-Painter"
"Creates a chalk type effect from an image. Will NOT work on INDEXED images. On larger images use greater depth settings"
"Rod Detmer"
"Rod Detmer"
"November 2015"
"RGB* GRAY*"
SF-IMAGE "The Image" 0
SF-DRAWABLE "The Drawable" 0
;SF-ADJUSTMENT "Depth (set higher for larger images)" '(100 25 100 1 10 0 SF-Spinner)
SF-ADJUSTMENT "Contrast (higher = darker)" '(127 0 127 1 10 0 SF-Spinner)
SF-ENUM "Chalk Layer mode" '("LayerModeEffects" "value-mode")                          

)
;
(script-fu-menu-register "script-fu-chalk-painter" "<Image>/Rod/Artistic")
