;;; Plugin  : rd colored pencil
;;; Author  : Rod Detmer
;;; Date    : October 24th 2015
;;; Revision: None
;;; 					
;;; Version : 1.0
;;; Latest version at: http://www.gimpchat.com
;;; Required : Gimp 2.8 or later
;;;
;;; Description: 
;;; creates a colored pencil type effect on an image. Images with more colors result in a better outcome
;;; -----------------------------------------------------------------------------
;;;
;;; License:
;;; This program is free software; you can redistribute it and/or modify
;;; it under the terms of the GNU General Public License as published by
;;; the Free Software Foundation; either version 2 of the License, or
;;; (at your option) any later version.
;;; 
;;; This program is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;; 
;;; You should have received a copy of the GNU General Public License
;;; along with this program; if not, write to the Free Software
;;; Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

(define (script-fu-rd-colored-pencil image drawable Depth Contrast)
  
  (gimp-context-push)  
  (gimp-image-undo-group-start image)

            (let* ((coloredpencillayer (car (gimp-layer-new-from-visible image image "Colored Pencil layer"))))
				      ;copy the image to a new layer and name it
                (gimp-image-add-layer image coloredpencillayer 0)
  
    ;create a embroidered looking effect on top layer to begin paint effect
  (plug-in-neon RUN-NONINTERACTIVE image coloredpencillayer 6.10 0.07)
  (plug-in-spread RUN-NONINTERACTIVE image coloredpencillayer 3 3)

   
   ;paint by spreading pixels around the top layer and set the layer mode to SCREEN
  (plug-in-neon RUN-NONINTERACTIVE image coloredpencillayer 1.0 1.0)  
  (gimp-layer-set-mode coloredpencillayer  LAYER-MODE-HARD-MIX)
  (gimp-layer-set-opacity coloredpencillayer Depth)
  (gimp-brightness-contrast coloredpencillayer 0 Contrast)  
  ;display the new image
  (gimp-displays-flush image)
  
  (gimp-context-pop)
  (gimp-image-undo-group-end image)
            )
  
)


(script-fu-register "script-fu-rd-colored-pencil"
"RD-Colored-Pencil"
"creates a colored pencil type effect on an image. on larger images use greater depth settings"
"Rod Detmer"
"Rod Detmer"
"October 2015"
"RGB* GRAY*"
SF-IMAGE "The Image" 0
SF-DRAWABLE "The Drawable" 0
SF-ADJUSTMENT "Depth" '(100 25 100 1 10 0 SF-Spinner)
SF-ADJUSTMENT "Contrast" '(0 0 127 1 10 0 SF-Spinner)
)

(script-fu-menu-register "script-fu-rd-colored-pencil" "<Image>/Rod/Artistic")
