;;; Plugin  : Neon Chalk Painter
;;; Author  : Rod Detmer
;;; Date    : November 2015
;;; Revision: None
;;; 					
;;; Version : 1.0
;;; Latest version at: http://www.gimpchat.com
;;; Required : Gimp 2.8 or later
;;;
;;; Description: 
;;; creates a painting type effect on an image. Images with more colors result in a better outcome
;;; -----------------------------------------------------------------------------
;;;
;;; License:
;;; This program is free software; you can redistribute it and/or modify
;;; it under the terms of the GNU General Public License as published by
;;; the Free Software Foundation; either version 2 of the License, or
;;; (at your option) any later version.
;;; 
;;; This program is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;; 
;;; You should have received a copy of the GNU General Public License
;;; along with this program; if not, write to the Free Software
;;; Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

(define (script-fu-neon-chalk-painter image drawable depth contrast)
  
  (gimp-context-push)  
  (gimp-image-undo-group-start image)
    ;make all visible paintedlayer and run new from visible making sure its named Painted layer
            (let* ((paintedlayer (car (gimp-layer-new-from-visible image image "painted layer"))))
	;paste or add the visible image to a new layer
  (gimp-image-add-layer image paintedlayer 0)
  
    ;begin paint effect on new layer
  (plug-in-neon RUN-NONINTERACTIVE image paintedlayer 6.10 0.07)


   
   ;paint by spreading pixels around the top layer
  (plug-in-spread RUN-NONINTERACTIVE image paintedlayer 3 3)   
  (plug-in-neon RUN-NONINTERACTIVE image paintedlayer 1.0 1.0)  
  (gimp-layer-set-mode paintedlayer LAYER-MODE-HSV-VALUE-LEGACY)
  
  ;set paint depth
  (gimp-layer-set-opacity paintedlayer depth)
  (gimp-brightness-contrast paintedlayer 0 contrast)
  (plug-in-gauss 1 image paintedlayer 3 3 1)
  ;(gimp-invert paintedlayer)
  ;(gimp-layer-copy paintedlayer 0)
  ;display the new image
  (gimp-displays-flush image)
  
  (gimp-context-pop)
  (gimp-image-undo-group-end image)
            )
  
)


(script-fu-register "script-fu-neon-chalk-painter"
"Neon-Chalk-Painter"
"Creates a painting type effect on an image. Will NOT work on INDEXED images. On larger images use greater depth settings"
"Rod Detmer"
"Rod Detmer"
"November 2015"
"RGB* GRAY*"
SF-IMAGE "The Image" 0
SF-DRAWABLE "The Drawable" 0
SF-ADJUSTMENT "Depth (set higher for larger images)" '(100 25 100 1 10 0 SF-Spinner)
SF-ADJUSTMENT "Contrast (higher = darker)" '(127 0 127 1 10 0 SF-Spinner)
;SF-ENUM "LayerMode" '("LayerModeEffects" "value-mode")
; SF-OPTION	  "Painting Mode" '( "VALUE-MODE" 
                                 ; "DISSOLVE-MODE" 
								 ; "BEHIND-MODE" 
								 ; "MULTIPLY-MODE" 
								 ; "SCREEN-MODE" 
								 ; "OVERLAY-MODE" 
								 ; "DIFFERENCE-MODE" 
								 ; "ADDITION-MODE" 
								 ; "SUBTRACT-MODE" 
								 ; "DARKEN-ONLY-MODE" 
								 ; "LIGHTEN-ONLY-MODE" 
								 ; "HUE-MODE" 
								 ; "SATURATION-MODE" 
								 ; "COLOR-MODE" 
								 ; "NORMAL-MODE" 
								 ; "DIVIDE-MODE" 
								 ; "DODGE-MODE" 
								 ; "BURN-MODE" 
								 ; "HARDLIGHT-MODE" 
								 ; "SOFTLIGHT-MODE" 
								 ; "GRAIN-EXTRACT-MODE" 
								 ; "GRAIN-MERGE-MODE" 
								 ; "COLOR-ERASE-MODE" 
								 ; "ERASE-MODE" 
								 ; "REPLACE-MODE" 
								 ; "ANTI-ERASE-MODE"
								 ; )
                          

)
;
(script-fu-menu-register "script-fu-neon-chalk-painter" "<Image>/Rod/Artistic")
